@@ -316,7 +316,13 @@ def read(filename, stack_object, selection=None, *args, **kwargs):
             if 'axes' in dsdata.attrs:
                 data_struct.exchange.data_axes = dsdata.attrs['axes']
 
-
+                if 'x' in exchangeGrp:
+                    dsx = exchangeGrp['x']
+                    data_struct.exchange.x = dsx[...]
+                    data_struct.have_dimscale = 1
+                if 'y' in exchangeGrp:
+                    dsy = exchangeGrp['y']
+                    data_struct.exchange.y = dsy[...]
 #
 #                 if 'x' in detectorGrp:
 #                     dsx = detectorGrp['x']
