@@ -18,28 +18,32 @@
 
 import sys
 import os
-import getopt
 import numpy as np
 import matplotlib
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 #from matplotlib.backends.backend_qt5agg import FigureCanvas
 from matplotlib.figure import Figure
-from mpl_toolkits.axes_grid1.axes_divider import make_axes_locatable
-from mpl_toolkits.axes_grid1.colorbar import colorbar
-#from mpl_toolkits.axes_grid1 import make_axes_locatable
+from mpl_toolkits.axes_grid1 import make_axes_locatable
+from matplotlib import colorbar
 
-import data_struct
-import data_stack
-import analyze
-import henke
+#Internal imports
+from . import data_struct
+from . import data_stack
+from . import analyze
+from . import nnma
+from . import henke
+from . import tomo_reconstruction
 
-import file_plugins
-from file_plugins import file_xrm
-from file_plugins import file_bim
-from file_plugins import file_dataexch_hdf5
-from file_plugins import file_ncb
-from file_plugins import file_tif
-from file_plugins import file_stk
+from . import file_plugins
+from .file_plugins import file_xrm
+from .file_plugins import file_bim
+from .file_plugins import file_dataexch_hdf5
+from .file_plugins import file_ncb
+from .file_plugins import file_json
+from .file_plugins import file_tif
+from .file_plugins import file_stk
+from .file_plugins import file_csv
+    
 
 PlotH = 4.0
 PlotW = PlotH*1.61803
@@ -768,27 +772,8 @@ def main():
 
     verbose = True
 
-    run_qt = 1
-    run_cl = 0
-    arguments = sys.argv[1:]
-    try:
-        options, extraParams = getopt.getopt(arguments, '', ['batch', 'nnma'])
-    except:
-        print('Error - wrong command line option used. Available options are --batch and --nnma')
-        return
-
-    for opt, arg in options:
-        if opt in '--batch':
-            run_qt = 0
-            run_cl = 1
-
-
-    if run_qt == 1:
-        import mantis_qt
-        m_qt = mantis_qt.main()
-    elif run_cl == 1:
-        print('Running Mantis in batch mode.')
-        batch_mode()
+    print('Running Mantis in batch mode.')
+    batch_mode()
 
     sys.exit()
 
